@@ -45,17 +45,16 @@ main (gint argc, gchar **argv)
         bindtextdomain (PACKAGE, LOCALEDIR);
         textdomain (PACKAGE);
 
-        gtk_init (&argc, &argv);
+        gtk_init_with_args (
+                &argc, &argv, NULL, NULL, GETTEXT_PACKAGE, &error);
+        if (error != NULL)
+                g_error ("%s", error->message);
+        
         gtk_window_set_default_icon_name (PACKAGE);
 
         if (!gva_game_db_init (&error))
                 g_error ("%s", error->message);
 
-        if (!gva_game_db_update_samples (&error)) {
-                g_warning ("%s", error->message);
-                g_clear_error (&error);
-        }
-
         gva_main_init ();
         gva_play_back_init ();
         gva_preferences_init ();
